==> ebtorch-0.5.8.tar.gz: ebtorch-0.5.8/ebtorch/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ==============================================================================
#
# Copyright 2020-* Emanuele Ballarin <emanuele@ballarin.cc>
# All Rights Reserved. Unless otherwise explicitly stated.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# ==============================================================================
#
# SPDX-License-Identifier: Apache-2.0
# Imports (wildcard)
from .logging import *
from .nn import *
from .optim import *

# Deletions (from .nn)
del AdaptiveInput
del AdaptiveLogSoftmaxWithLoss
del ArgMaxLayer
del BrokenReLU
del CausalConv1d
del ConvolutionalFlattenLayer
del FCBlock
del FCBlockLegacy
del FieldTransform
del FlatChannelize2DLayer
del GaussianReparameterizerSampler
del KWTA1d
del KWTA2d
del LMUCell
del Mish
del MishPulse
del MishPulseSymmY
del ProbePrintLayer
del ReshapeLayer
del SERLU
del SGRUHCell
del SmeLU
del VariationalDropout
del field_transform
del mishlayer_init
del mishpulse
del mishpulse_symmy

# Deletions (from .optim)
del Adan
del ralah_optim
del HCAdam
del HCGD
del Lookahead
del MADGRAD
del PlainRAdam
del RAdam
del SAM
del WarmAdamW

# Deletions (from .logging)
del AverageMeter
del LogCSV

==> ebtorch-0.6.1.tar.gz: ebtorch-0.6.1/ebtorch/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# ==============================================================================
#
# Copyright 2020-* Emanuele Ballarin <emanuele@ballarin.cc>
# All Rights Reserved. Unless otherwise explicitly stated.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# ==============================================================================
#
# SPDX-License-Identifier: Apache-2.0
# Imports (wildcard)
from .logging import *
from .nn import *
from .optim import *

# Deletions (from .nn)
del AdaptiveInput
del AdaptiveLogSoftmaxWithLoss
del ArgMaxLayer
del BrokenReLU
del CausalConv1d
del ConvolutionalFlattenLayer
del FCBlock
del FCBlockLegacy
del NNEnsemble
del FieldTransform
del FlatChannelize2DLayer
del GaussianReparameterizerSampler
del KWTA1d
del KWTA2d
del LMUCell
del Mish
del MishPulse
del MishPulseSymmY
del ProbePrintLayer
del ReshapeLayer
del SERLU
del SGRUHCell
del SmeLU
del VariationalDropout
del field_transform
del mishlayer_init
del mishpulse
del mishpulse_symmy
del pixelwise_bce_mean
del pixelwise_bce_sum
del BinarizeLayer

# Deletions (from .optim)
del Adan
del ralah_optim
del HCAdam
del HCGD
del Lookahead
del MADGRAD
del RAdam
del SAM

# Deletions (from .logging)
del AverageMeter
del LogCSV
